@@ -1,22 +1,3 @@
-$.fn.hasOverflow = function() {
-    var $this = $(this);
-    var $children = $this.find('.tileMedia');
-    var len = $children.length;
-
-    if (len) {
-        var maxWidth = 0;
-        var maxHeight = 0
-        $children.map(function(){
-            maxWidth = Math.max(maxWidth, $(this).outerWidth(true));
-            maxHeight = Math.max(maxHeight, $(this).outerHeight(true));
-        });
-
-        return maxWidth > $this.width() || maxHeight > $this.height();
-    }
-
-    return false;
-};
-
 Arnolfini = {};
 
 Arnolfini.bodyclick = false
@@ -109,6 +90,87 @@ Arnolfini.events = function ()
 mediaShow.buttonPrevContent = "&larr;";
 mediaShow.buttonNextContent = "&rarr;";
 
+//Override slideshow behaviour
+//Show the next slide in the given slideshow
+mediaShow.next = function (slideshowIndex)
+{
+  var slideshow = mediaShow.slideshows[slideshowIndex];
+  if(slideshow.currentSlide + 1 <= slideshow.size - 1)
+  { 
+    mediaShow.goToSlide(slideshow.currentSlide + 1, slideshow); 
+  }
+  else
+  {
+    Arnolfini.getNextEvent()
+  }
+  
+  return false;
+}
+
+//Show the previews slide in given slideshow
+mediaShow.prev = function (slideshowIndex)
+{
+  var slideshow = mediaShow.slideshows[slideshowIndex];
+  if(slideshow.currentSlide - 1 >= 0)
+  {
+    mediaShow.goToSlide(slideshow.currentSlide - 1, slideshow);
+  }
+  else
+  {
+    Arnolfini.getPrevEvent()
+  }
+  
+  return false;
+}
+
+//This reads the URL hash and updates the slideshows acordingly
+mediaShow.readURLAndUpdate = function ()
+{
+  var hash = document.location.hash;
+  if(hash == "")
+    return;
+  
+  if(hash == "#lastpic")
+  {
+	document.location.hash = "";
+	$.each(mediaShow.slideshows, function(index, slideshow)
+	       {
+			mediaShow.updateURL(slideshow, slideshow.slides.length -1);
+	       });
+  }
+  
+  var hash_split = hash.substring(1,hash.length).split(",");
+  $.each(hash_split, function(index, hsh){
+    $.each(mediaShow.slideshows, function(index, slideshow){
+      var slideIndex = mediaShow.idToIndex(slideshow, hsh);
+      if (slideIndex > -1)
+      {
+        slideshow.hash = hsh;
+        mediaShow.goToSlide(slideIndex, slideshow);
+        return false;
+      }
+      return true;
+    });
+  });
+};
+
+Arnolfini.getNextEvent = function ()
+{
+	if (onSlodeshowSkipNext !== null)
+	{
+		window.location = onSlodeshowSkipNext;
+	}
+	
+}
+
+Arnolfini.getPrevEvent = function ()
+{
+	if (onSlodeshowSkipPrev!== null)
+	{
+		window.location = onSlodeshowSkipPrev + "#lastpic";
+	}
+}
+
 $(document).ready(function() {
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
