@@ -8,6 +8,7 @@ from Products.CMFPlone.PloneBatch import Batch
 from datetime import date
 from DateTime import DateTime
 from plone.app.querystring import queryparser
+import re
 
 
 class CommonBrowserView(BrowserView):
@@ -32,6 +33,20 @@ class CommonBrowserView(BrowserView):
         if lead is not None:
             return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
     
+    def trimText(self, text, limit, strip=False):
+        if strip:
+            text = self.stripTags(text)
+    
+        if len(text) > limit: 
+            res = text[0:limit]
+            lastspace = res.rfind(" ")
+            res = res[0:lastspace] + " ..."
+            return res
+        else:
+            return text
+            
+    def stripTags(self, text):
+        return re.sub('<[^<]+?>', '', text)
     
     def getTwoWayRelatedContent(self):
         """
@@ -47,7 +62,7 @@ class CommonBrowserView(BrowserView):
         
     def getContentAsLinks(self, content):
         """
-        A commodity, this formats a content list content as an HTML structure of titles with links. Comma separated.
+        A commodity, this formats a content list content as an HTML structure of titles with links. Comma separated. Used to list the artists related to an exhibition.
         """
         result = []
         for res in content:
@@ -86,8 +101,47 @@ class EventView(CommonBrowserView):
     """'
      Override of media event view class.
     """
+    nxt = None
+    prv = None
     
-class EventArchiveView(CommonBrowserView):
+    def cacheNextPrev(self):
+        """
+        Caches the values for next and prev
+        """
+        catalog = getToolByName(self.context, 'portal_catalog')
+        results = catalog.queryCatalog({"portal_type": "Media Event",
+                                 "sort_on": "start",
+                                 "hasMedia": True,
+                                 "review_state": "published"})
+        
+        for i in range(0, len(results)):
+            if results[i].UID == self.context.UID():
+                if i < len(results) - 2:
+                    self.nxt = results[i +1]
+    
+                if i > 0:
+                    self.prv = results[i -1]
+    
+    def getNextEvent(self):
+        """
+        Gets the next event in chronological order.
+        """
+        if self.nxt is None:
+            self.cacheNextPrev()
+        
+        return self.nxt
+    
+    def getPrevEvent(self):
+        """
+        Gets the previous event in chronological order
+        """
+        if self.prv is None:
+            self.cacheNextPrev()
+        
+        return self.prv
+        
+    
+class EventArchiveView(EventView):
     """'
     Event archive view class.
     """
@@ -107,6 +161,7 @@ class EventArchiveListingView(CommonBrowserView):
     def innerResults(self, item, limit=3):
         #TODO: If we can query specifically for the hasMedia then we don't need to bypass the batching anymore
         all_results = item.getObject().queryCatalog(batch=False)
+        
         final_res = []
         
         for res in all_results:
@@ -128,13 +183,11 @@ class EventArchiveListingView(CommonBrowserView):
             results = catalog.queryCatalog({"portal_type": "Media Event",
                                  "start": date_range_query,
                                  "sort_on": "start",
-                                 "sort_order": "reverse",
                                  "review_state": "published"})
         else:
             results = catalog.queryCatalog({"portal_type": "Media Event",
                                  "start": date_range_query,
                                  "sort_on": "start",
-                                 "sort_order": "reverse",
                                  "review_state": "published",
                                  "hasMedia": True})
             
@@ -180,6 +233,16 @@ class FolderListing(CommonBrowserView):
     """'
     Override of folder_listing view
     """
+    def results(self, b_start = 0, pagesize=10):
+        
+        if self.context.portal_type  == 'Collection':
+            results = self.context.queryCatalog(batch=True, b_start = b_start, b_size=pagesize)
+        elif self.context.portal_type  == 'folder':
+            brains = self.context.getFolderContents()
+            final_res = list(brains)
+            results = Batch(final_res, pagesize, start=b_start)
+            
+        return results
     
 class SearchView(Search):
     """
